# 说明

为了方便您在自己的客户端业务中使用vod，这里给出了vod上传调用示例供参考。示例给出了如何申请上传媒资，完成上传（含处理）的具体方法。

# 快速开始

- 工程依赖

app-server-example基于jdk17,springboot3.0开发，依赖百度智能云vod-sdk，导入项目完成之后需下载对应maven依赖。

- 工程结构说明

controller包中提供了接口访问，目前已实现上传，确认上传(含媒资处理)接口。

service包中提供了具体实现，若已有接口不满足需求，可以参考vod-sdk进行开发。

application.yml中可配置您的ak sk用于vod-sdk鉴权，访问vod接口。

# 接口示例

- 上传

方法：POST

路径： /medias/upload

请求体：

```json
{
    "name": "server1",
    "container": "mp4",
    "isMultipartUpload": false,
    "numParts": 1
}
```

响应：

```json
{
    "urls": [
        "https://bj.bcebos.com/v1/vod-ehvqtv08x8wepw9h/tmp/ehvqhstanrcdgj5g2vz0/ejsqm8udstrnj74bxrbg.mp4?authorization=bce-auth-v1%2F66c557960e7a4822bd82c772a1409590%2F2024-10-17T06%3A35%3A56Z%2F86400%2Fhost%2F6164785e19cb743930094d01efb9298a22cfe4e5469452813ff119aafe29639b"
    ],
    "sessionKey": "ZEcxd0wyVm9kbkZvYzNSaGJuSmpaR2RxTldjeWRub3dMMlZxYzNGdE9IVmtjM1J5Ym1vM05HSjRjbUpuTG0xd05BPT1fX2MyVnlkbVZ5TVE9PQ=="
}
```

- 分片上传

方法：POST

路径：/medias/upload

请求体：

```json
{
    "name": "server1",
    "container": "mp4",
    "isMultipartUpload": true,
    "numParts": 2
}
```

响应：

```json
{
    "urls": [
        "https://bj.bcebos.com/v1/vod-ehvqtv08x8wepw9h/tmp/ehvqhstanrcdgj5g2vz0/ejss6mv44nj49syam37b.mp4?uploadId=53c8f4f901bbc465292ea6c82fbc8756A&partNumber=1&authorization=bce-auth-v1%2F66c557960e7a4822bd82c772a1409590%2F2024-10-17T08%3A26%3A05Z%2F86400%2Fhost%2F4dc3bc48a4fe0445be871afaf8db88f7b34952524c18eabe73105c9e68cd4df2",
        "https://bj.bcebos.com/v1/vod-ehvqtv08x8wepw9h/tmp/ehvqhstanrcdgj5g2vz0/ejss6mv44nj49syam37b.mp4?uploadId=53c8f4f901bbc465292ea6c82fbc8756A&partNumber=2&authorization=bce-auth-v1%2F66c557960e7a4822bd82c772a1409590%2F2024-10-17T08%3A26%3A05Z%2F86400%2Fhost%2F7a6a92cf9f118623eb4163cf4d08ef810641a2c5436d00bd40616519c9787c6b"
    ],
    "sessionKey": "ZEcxd0wyVm9kbkZvYzNSaGJuSmpaR2RxTldjeWRub3dMMlZxYzNNMmJYWTBORzVxTkRsemVXRnRNemRpTG0xd05BPT1fX2MyVnlkbVZ5TVE9PV9fTlROak9HWTBaamt3TVdKaVl6UTJOVEk1TW1WaE5tTTRNbVppWXpnM05UWkI="
}
```

- 完成上传并自动提取封面图

方法：POST

路径：/medias/upload_done

请求体：

```json
{
    "isMultipartUpload": true,
    "etags": [
        "5586ccfaf7301163d6021c4b82971ae1",
        "94017cad66d9e126296f94828035e366"
    ],
    "sessionKey": "ZEcxd0wyVm9kbkZvYzNSaGJuSmpaR2RxTldjeWRub3dMMlZxYzNFMGNUWjVhVFZvZG1SbGJXVXpablIyTG0xd05BPT1fX2MyVnlkbVZ5TXc9PV9fWWpCbFlUVXhZamt6TTJWaVptTmxPR0ZqTlRsa01XRTBZamhqTURjNE9UbEI=",
    "autoExtractCover": true
}
```

响应：

```json
{
    "mediaId": "mda-jkjiis93ns"
}
```

- 完成上传并自动提取封面图和使用工作流处理

方法：POST

路径：/medias/upload_done

请求体：

```json
{
    "isMultipartUpload": true,
    "etags": [
        "5586ccfaf7301163d6021c4b82971ae1",
        "94017cad66d9e126296f94828035e366"
    ],
    "sessionKey": "ZEcxd0wyVm9kbkZvYzNSaGJuSmpaR2RxTldjeWRub3dMMlZxYzNFMGNUWjVhVFZvZG1SbGJXVXpablIyTG0xd05BPT1fX2MyVnlkbVZ5TXc9PV9fWWpCbFlUVXhZamt6TTJWaVptTmxPR0ZqTlRsa01XRTBZamhqTURjNE9UbEI=",
    "autoExtractCover": true,
    "needProcess":true,
    "workflow": {
        "workflowId": "ejsq6j92wv5y1n6ju4et"
    }
}
```

响应：

```json
{
    "mediaId": "mda-ejsqhbc6wde39uu",
    "taskId":"tsk-ejsqhbc6wj9db9uu"
}
```



# 如何联系我们

使用的过程中如果有疑问，可通过控制台联系客服，收到工单之后我们会第一时间进行响应。