package com.baidu.bce.vod.server.service.impl;

import com.baidu.bce.vod.server.dto.MediaUploadCompltedRequest;
import com.baidu.bce.vod.server.error.MediasException;
import com.baidu.bce.vod.server.service.MediaService;
import com.baidubce.auth.DefaultBceCredentials;
import com.baidubce.services.vod.v2.VodClient;
import com.baidubce.services.vod.v2.VodClientConfiguration;
import com.baidubce.services.vod.v2.model.MediaCompleteUploadResponse;
import com.baidubce.services.vod.v2.model.MediaProcessRequest;
import com.baidubce.services.vod.v2.model.MediaProcessResponse;
import com.baidubce.services.vod.v2.model.MediaUploadDoneRequest;
import com.baidubce.services.vod.v2.model.MediaUploadRequest;
import com.baidubce.services.vod.v2.model.MediaUploadResponse;
import jakarta.annotation.PostConstruct;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

@Service
public class MediaServiceImpl implements MediaService {
    @Value("${vod.ak}")
    private String ak;
    @Value("${vod.sk}")
    private String sk;
    @Value("${vod.endpoint}")
    private String endpoint;
    private VodClient vodClient;
    @Override
    public MediaUploadResponse createUpload(MediaUploadRequest request) {
        return vodClient.createUpload(request);
    }

    @Override
    public MediaProcessResponse completeUpload(MediaUploadCompltedRequest request) {
        MediaUploadDoneRequest mediaUploadDoneRequest = new MediaUploadDoneRequest();
        mediaUploadDoneRequest.setMultipartUpload(request.isMultipartUpload());
        mediaUploadDoneRequest.setEtags(request.getEtags());
        mediaUploadDoneRequest.setSessionKey(request.getSessionKey());
        mediaUploadDoneRequest.setAutoExtractCover(request.isAutoExtractCover());
        MediaCompleteUploadResponse mediaCompleteUploadResponse = completeUpload(mediaUploadDoneRequest);
        MediaProcessResponse mediaProcessResponse = new MediaProcessResponse();
        mediaProcessResponse.setMediaId(mediaCompleteUploadResponse.getMediaId());
        if (request.isNeedProcess()) {
            if (request.getWorkflow() == null && request.getPreset() == null) {
                throw new MediasException.ProcessFailed("workflow and preset both are empty.");
            }
            MediaProcessRequest mediaProcessRequest = new MediaProcessRequest();
            mediaProcessRequest.setMediaId(mediaCompleteUploadResponse.getMediaId());
            mediaProcessRequest.setWorkflow(request.getWorkflow());
            mediaProcessRequest.setPreset(request.getPreset());
            MediaProcessResponse processed = processMedia(mediaProcessRequest);
            mediaProcessResponse.setTaskId(processed.getTaskId());
        }
        return mediaProcessResponse;
    }

    @Override
    public MediaCompleteUploadResponse completeUpload(MediaUploadDoneRequest request) {
        return vodClient.completeUpload(request);
    }

    @Override
    public MediaProcessResponse processMedia(MediaProcessRequest mediaProcessRequest) {
        return vodClient.processMedia(mediaProcessRequest);
    }

    @PostConstruct
    public void getVodClient() {
        VodClientConfiguration configuration = new VodClientConfiguration().withCredentials(new DefaultBceCredentials(ak, sk))
                .withEndpoint(endpoint);
        vodClient = new VodClient(configuration);
    }
}
